==> javautils-jexpression-1.3.0-sources.jar: tecgraf/javautils/jexpression/samples/Calculator.java <==
package tecgraf.javautils.jexpression.samples;

import java.util.Scanner;

import tecgraf.javautils.jexpression.JExpression;
import tecgraf.javautils.jexpression.util.CalculatorHandler;

/**
 * Utilitrio que calcula a dada expresso.
 * 
 * @author Tecgraf
 */
public class Calculator {

  /**
   * Programa.
   * 
   * @param args argumentos.
   */
  public static void main(String[] args) {
    Scanner scanner = new Scanner(System.in);

    CalculatorHandler handler = new CalculatorHandler();

    while (true) {
      System.out.println("Digite expresso (opes: 'help' e 'exit'):");

      String line = scanner.nextLine();
      if (line.contains("help")) {
        System.out.println("Para definir variveis: define <nome> <valor>");
        continue;
      }
      if (line.contains("define")) {
        String[] values = line.split(" +");
        if (values.length != 3) {
          System.out.println("Operao 'define' requer 2 argumentos.");
          continue;
        }
        Object value = getValue(values[2]);
        handler.addVariable(values[1], value);
        continue;
      }
      if (line.contains("exit")) {
        break;
      }
      evaluate(line, handler);
    }
  }

  /**
   * Retorna um valor {@link Boolean} ou {@link Double} de acordo com a dada
   * {@link String}.
   * 
   * @param value valor {@link String}.
   * @return valor.
   */
  private static Object getValue(String value) {
    if (value.equals("true")) {
      return true;
    }
    if (value.equals("false")) {
      return false;
    }
    return Double.valueOf(value);
  }

  /**
   * Avalia a expresso.
   * 
   * @param entry entrada.
   * @param handler tratador de expresses.
   */
  private static void evaluate(String entry, CalculatorHandler handler) {
    try {
      JExpression expression = JExpression.compile(entry);
      Object result = expression.eval(handler);
      System.out.println(result);
    }
    catch (Exception e) {
      System.out.println(e.getMessage());
    }
  }
}

==> javautils-jexpression-2.0.0-sources.jar: tecgraf/javautils/jexpression/samples/Calculator.java <==
package tecgraf.javautils.jexpression.samples;

import java.nio.charset.Charset;
import java.util.Scanner;

import tecgraf.javautils.jexpression.JExpression;
import tecgraf.javautils.jexpression.util.CalculatorHandler;

/**
 * Utilitrio que calcula a dada expresso.
 * 
 * @author Tecgraf
 */
public class Calculator {

  /**
   * Programa.
   * 
   * @param args argumentos.
   */
  public static void main(String[] args) {
    final Charset charset = Charset.defaultCharset();
    Scanner scanner = new Scanner(System.in, charset.name());

    CalculatorHandler handler = new CalculatorHandler();

    while (true) {
      System.out.println("Digite expresso (opes: 'help' e 'exit'):");
      String line = scanner.nextLine();
      if (line.contains("help")) {
        System.out.println("Para definir variveis: define <nome> <valor>");
        continue;
      }
      if (line.contains("define")) {
        String[] values = line.split(" +");
        if (values.length != 3) {
          System.out.println("Operao 'define' requer 2 argumentos.");
          continue;
        }
        Object value = getValue(values[2]);
        handler.addVariable(values[1], value);
        continue;
      }
      if (line.contains("exit")) {
        break;
      }
      evaluate(line, handler);
    }
  }

  /**
   * Retorna um valor {@link Boolean} ou {@link Double} de acordo com a dada
   * {@link String}.
   * 
   * @param value valor {@link String}.
   * @return valor.
   */
  private static Object getValue(String value) {
    if (value.equals("true")) {
      return true;
    }
    if (value.equals("false")) {
      return false;
    }
    return Double.valueOf(value);
  }

  /**
   * Avalia a expresso.
   * 
   * @param entry entrada.
   * @param handler tratador de expresses.
   */
  private static void evaluate(String entry, CalculatorHandler handler) {
    try {
      JExpression expression = JExpression.compile(entry);
      Object result = expression.eval(handler);
      System.out.println(result);
    }
    catch (Exception e) {
      System.out.println(e.getMessage());
    }
  }
}
